@@ -9,6 +9,7 @@ import pygame
 from pygame.locals import *
 import random
 import os
+import sys
 
 pygame.init()
 
@@ -20,6 +21,17 @@ SCREEN_HEIGHT = ENV_HEIGHT * 50 #height of the window
 
 #NUM_ENEMIES = 4
 
+path_parent = os.path.dirname(os.getcwd())
+sys.path.insert(1, path_parent)\
+
+
+game_folder = os.path.dirname(__file__)
+img_folder = os.path.join(game_folder, "img")
+background_file = os.path.join(img_folder, "starfield.png")
+player_file = os.path.join(img_folder, "playerShip1_orange.png")
+meteorite_file = os.path.join(img_folder, "meteorBrown_med1.png")
+explosion_file = os.path.join(img_folder, "regularExplosion01.png")
+
 
 #define colors
 WHITE = (255, 255, 255)
@@ -77,7 +89,7 @@ class Enemy(pygame.sprite.Sprite):
             self.round+=1
 
 class env:
-    def __init__(self, background_file, player_file, meteorite_file, num_enemies = 4, num_rounds = 10):
+    def __init__(self,num_enemies = 4, num_rounds = 10):
         #Set up screen
         self.screen = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))
         self.background = pygame.image.load(background_file)
@@ -102,13 +114,20 @@ class env:
         
         self.done = 0
 
-    def get_objs_observation_space_high(self):
+    def get_state_space_high(self):
         obs = [ENV_WIDTH]+([ENV_WIDTH]*self.num_enemies)
         return np.array(obs, dtype=float)
     
-    def get_objs_observation_space_low(self):
+    def get_state_space_low(self):
         obs = [0]+([-ENV_WIDTH]*self.num_enemies)
         return np.array(obs, dtype=float)
+		
+    def get_state_space_size(self):
+        discrete_os_win_size = [10]+[20]*(self.num_enemies)
+        return discrete_os_win_size
+
+    def get_action_space_size(self):
+        return [3]
         
     def sortSecond(self, List):
         return List[1]
